@@ -6,24 +6,23 @@ from timbermill.timberlog import timberlog_start
 
 @timberlog_start
 def decorator_success():
-    pass
+    timberlog.info(context={'msg': 'this is a successful decorator task'})
 
 
 @timberlog_start
 def decorator_fail():
+    timberlog.info(context={'msg': 'this is a unsuccessful decorator task'})
     raise Exception()
 
 
 def success():
     with timberlog.start_task('context_manager_success') as t:
-        s = 'this is a successful task'
-        t.info(context={'msg': s})
+        t.info(context={'msg': 'this is a successful task'})
 
 
 def fail():
     with timberlog.start_task('context_manager_fail') as t:
-        s = 'this is an unsuccessful task'
-        t.info(context={'msg': s})
+        t.info(context={'msg': 'this is an unsuccessful task'})
 
         raise Exception()
 
