@@ -122,6 +122,11 @@ def add_metrics(**kwargs):
 
 
 def info(context: dict = None, strings: dict = None, metrics: dict = None, text: dict = None):
+    global inited
+    if not inited:
+        logging.getLogger(__name__).error('Trying to create a new timbermill spot event without it being inited, ignoring..')
+        return None
+
     stack = __get_stack()
 
     if stack.is_empty():
@@ -183,7 +188,7 @@ def __clear_local_data():
         task_id_stack.clear()
 
 
-def __create_end_event(event_type: str, text: dict = {}) -> dict:
+def __create_end_event(event_type: str, text: dict = None) -> dict:
     stack = __get_stack()
 
     if stack.is_empty():
