@@ -72,7 +72,11 @@ def init_timbermill():
 
 def create_event(event_type: str, text: dict, name: str = None, task_id: str = None, context: dict = None, strings: dict = None, metrics: dict = None, parent_id: str = None, retention_days: int = None,
                  event_time: str = None, status: bool = None) -> dict:
-    context, strings, metrics, text = init_dict_args([context, strings, metrics, text])
+    text = text if text is not None else {}
+    context = context if context is not None else {}
+    strings = strings if strings is not None else {}
+    metrics = metrics if metrics is not None else {}
+
     if not event_time:
         event_time = __get_current_time_formatted()
 
@@ -104,11 +108,6 @@ def create_event(event_type: str, text: dict, name: str = None, task_id: str = N
     return event
 
 
-def init_dict_args(args: list):
-    res = [arg if arg is not None else {} for arg in args]
-    return tuple(res) if len(res) > 1 else res[0]
-
-
 def __should_add_static_event_params(event_type, name):
     return event_type == consts.EVENT_TYPE_START or \
            (event_type == consts.EVENT_TYPE_SPOT and name != consts.END_WITHOUT_START and name != consts.LOG_WITHOUT_CONTEXT)
